local Henhouse = ...

local myMonument = {
    DataType = "BUILDING",
    Id = "PV3_HENHOUSE",
    Name = "PV3_HENHOUSE_NAME",
    Description = "PV3_HENHOUSE_DESC",
    BuildingType = "GENERAL"
}

if (foundation.getGameVersion == nil or version.cmp(foundation.getGameVersion(), "1.6") < 0) then
    Henhouse:log("Hello World: version 1.5")
    myMonument.BuildingPartSetList = {
		{
			Name = "PV3_HENHOUSE_NAME",
                	BuildingPartList = { "PV3_HENHOUSE_PART" }
                }
    } 
    _vjrTagBehaviorWork = "WORK_BEHAVIOR"
else
    Henhouse:log("Hello World: version 1.6")
    myMonument.AssetCoreBuildingPart = "PV3_HENHOUSE_PART"
    _vjrTagBehaviorWork = "BEHAVIOR_WORK"
end

Henhouse:register(myMonument)

Henhouse:dofile("scripts/compHenHouse.lua")

-- Register prefab nodes (currently only one core model)
Henhouse:registerAssetId("models/henhouse.fbx/Prefab/henhousePart", "PV3_HENHOUSE_PREFAB")

-- Register the henhouse workplace part
Henhouse:register({
	DataType = "BUILDING_PART",
	Id = "PV3_HENHOUSE_PART",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PV3_HENHOUSE_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "WOOD", Quantity = 5 }
		}
	},
	AssetBuildingFunction = "FUNCTION_PV3_HENHOUSE"
})

Henhouse:register({
		DataType = "BUILDING_FUNCTION_WORKPLACE",
                Id = "FUNCTION_PV3_HENHOUSE",
		WorkerCapacity = 1,
                RelatedJob = { Job = "PV3_HEN_BREEDER", Behavior = _vjrTagBehaviorWork },
                InputInventoryCapacity = {
			{ Resource = "WHEAT", Quantity = 2 }
                },
                ResourceListNeeded = {
                	{ Resource = "WHEAT", Quantity = 1 }
                },
                ResourceProduced = {
			{ Resource = "PV3_EGG", Quantity = 4 }
                }
})

-- Register grass clearing components

Henhouse:registerPrefabComponent("models/henhouse.fbx/Prefab/henhousePart", {
	DataType = "COMP_DIRT_RECTANGLE",
	Size = {5, 5}
})

Henhouse:registerPrefabComponent("models/henhouse.fbx/Prefab/henhousePart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 4, 4 }
})

Henhouse:registerAssetId("models/henhouse.fbx/Prefab/henhousePart/step_1/door", "PV3_HENHOUSE_DOOR_PREFAB")

Henhouse:registerPrefabComponent("models/henhouse.fbx/Prefab/henhousePart", {
	DataType = "COMP_BUILDING_PART",
	FeedbackComponentListToActivate = {
		{ "PV3_HENHOUSE_DOOR_PREFAB", "PV3_HENHOUSE_DOOR_COMP" }
	}
})

Henhouse:registerPrefabComponent("models/henhouse.fbx/Prefab/henhousePart/step_1/door", {
	DataType = "PV3_HENHOUSE_DOOR_COMP",
	Enabled = false
})
Henhouse:registerPrefabComponent("models/henhouse.fbx/Prefab/henhousePart/step_1/door", {
	DataType = "COMP_GROUNDED"
})

--------------------------------------------------------------------------
function registerHen(_henNumber)
    Henhouse:registerPrefabComponent("models/henhouse.fbx/Prefab/henhousePart/poule" .. _henNumber .. "/groupMove" .. _henNumber, {
	DataType = "PV3_HENHOUSE_COMP",
	Enabled = true
    })
    Henhouse:registerPrefabComponent("models/henhouse.fbx/Prefab/henhousePart/poule" .. _henNumber, {
	DataType = "COMP_GROUNDED"
    })
end

registerHen(1)
registerHen(2)
registerHen(3)
